.. _resources:

Other resources and learning material
#####################################

Vyper has an active community. You can find third party tutorials,
examples, courses and other learning material.

General
-------

- `Ape Academy - Learn how to build vyper projects <https://academy.apeworx.io/>`__ by ApeWorX
- `More Vyper by Example <https://vyper-by-example.org/>`__ by Smart Contract Engineer
- `Vyper cheat Sheet <https://reference.auditless.com/cheatsheet>`__
- `Vyper Hub for development <https://github.com/zcor/vyper-dev>`__
- `Vyper greatest hits smart contract examples <https://github.com/pynchmeister/vyper-greatest-hits/tree/main/contracts>`__

Frameworks and tooling
----------------------

- `ApeWorX - The Ethereum development framework for Python Developers, Data Scientists, and Security Professionals <https://www.apeworx.io/>`__
- `Foundry x Vyper - Foundry template to compile Vyper contracts <https://github.com/0xKitsune/Foundry-Vyper>`__
- `Snekmate - Vyper smart contract building blocks <https://github.com/pcaversaccio/snekmate>`__
- `Serpentor - A set of smart contracts tools for governance <https://github.com/yearn/serpentor>`__
- `Smart contract development frameworks and tools for Vyper on Ethreum.org <https://ethereum.org/en/developers/docs/programming-languages/python/>`__

Security
--------

- `VyperPunk - learn to secure and hack Vyper smart contracts <https://github.com/SupremacyTeam/VyperPunk>`__
- `VyperExamples - Vyper vulnerability examples <https://www.vyperexamples.com/reentrancy>`__

Conference presentations
------------------------

- `Vyper Smart Contract Programming Language by Patrick Collins (2022, 30 mins) <https://www.youtube.com/watch?v=b-sOMNF9quo&t=1444s>`__
- `Python and DeFi by Curve Finance (2022, 15 mins) <https://www.youtube.com/watch?v=4HOU3z0LoDg>`__
- `My experience with Vyper over the years by Benjamin Scherrey (2022, 15 mins) <https://www.youtube.com/watch?v=_j7qF_GlyWE>`__
- `Short introduction to Vyper by Edison Que (3 mins) <https://www.youtube.com/watch?v=dXqln-keyHw&t=4s>`__

Unmaintained
------------

These resources have not been updated for a while, but may still offer interesting content.

- `Awesome Vyper curated resources <https://github.com/spadebuilders/awesome-vyper>`__
- `Brownie - Python framework for developing smart contracts (deprecated) <https://eth-brownie.readthedocs.io/en/stable/>`__
